import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1

/*
  The carousel is an element which displays a header title with a flickable row of ubuntu shape thumbnails.
  */
Item {
    id: carousel

    // Header Title
    property alias header: header.text

    // Carousel Data Model
    property alias dataModel: carouselList.model

    // Carousel Thumbnail size
    property int size: units.gu(12)

    // Signal triggered when a thumb
    signal thumbClicked(var model)

    height: container.height
    width: parent.width

    Column {
        id: container

        anchors.fill: parent
        spacing: units.gu(1)
        height: header.height + carouselList.height

        Header {
            id: header
            text: "Default Header Title"
            ActivityIndicator {
                running: dataModel.count === 0 ? true : false
                anchors.right: parent.right
            }
        }

        ListView {
            id: carouselList

            width: parent.width
            height: carousel.size + units.gu(10)
            orientation: Qt.Horizontal
            spacing: units.gu(2)

            // Element consists of a Picture and a text label below it.
            delegate: Item {
                id: thumbContainer

                width: carousel.size
                height: thumbColumn.height

                Column {
                    id: thumbColumn
                    spacing: units.gu(0.5)

                    // Widget to curve edges and encase the thumbnail
                    UbuntuShape {
                        id: carouselThumb

                        width: carousel.size
                        height: carousel.size + units.gu(5)

                        image: Image {
                            source: thumb_url != "null" ? thumb_url : Qt.resolvedUrl("../graphics/toolbarIcon.png")
                            fillMode: Image.PreserveAspectFit
                            smooth: true
                        }
                    }

                    // Label showing the movie/tv show name
                    Label {
                        id: carouselThumbDescription

                        text: name
                        maximumLineCount: 2
                        elide: Text.ElideRight
                        wrapMode: Text.WordWrap
                        width: carouselThumb.width
                        horizontalAlignment: Text.AlignHCenter
                    }
                }

                MouseArea {
                    anchors.fill: parent
                    onClicked: carousel.thumbClicked(model)
                }
            }
        }
    }
}
