import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1

Item {
    id: grid

    // Header Title
    property alias header: header.text

    // Grid Data Model
    property alias dataModel: gridView.model

    // Grid Thumbnail size
    property int size: units.gu(12)

    // Signal triggered when a thumb
    signal thumbClicked(var model)

    width: parent.width

    Column {
        id: container

        anchors.fill: parent
        spacing: units.gu(1)

        Header {
            id: header
            text: "Default Header Title"
            visible: text != "Default Header Title"
            ActivityIndicator {
                running: dataModel.count === 0 ? true : false
                anchors.right: parent.right
            }
        }

        Component {
            id: gridDelegate
            Item {
                id: thumbContainer

                width: grid.size + units.gu(2)
                height: thumbColumn.height

                Column {
                    id: thumbColumn
                    spacing: units.gu(0.5)
                    anchors.fill: parent

                    // Widget to curve edges and encase the thumbnail
                    UbuntuShape {
                        id: gridThumb

                        width: grid.size
                        height: grid.size + units.gu(5)

                        image: Image {
                            source: thumb_url
                            fillMode: Image.PreserveAspectFit
                            smooth: true
                        }

                        MouseArea {
                            anchors.fill: parent
                            onClicked: grid.thumbClicked(model)
                        }
                    }

                    // Label showing the movie/tv show name
                    Label {
                        id: gridThumbDescription

                        text: name
                        maximumLineCount: 2
                        elide: Text.ElideRight
                        wrapMode: Text.WordWrap
                        width: gridThumb.width
                        horizontalAlignment: Text.AlignHCenter

                        MouseArea {
                            anchors.fill: parent
                            onClicked: grid.thumbClicked(model)
                        }
                    }
                }
            }
        }


        GridView {
            id: gridView

            clip: true
            width: parent.width
            height: parent.height - header.height - parent.spacing
            snapMode: GridView.SnapToRow

            cellHeight: grid.size + units.gu(12)
            cellWidth: grid.size + container.spacing

            delegate: gridDelegate
        }

    }
}
