import QtQuick 2.0
import Ubuntu.Components 0.1
import QtGraphicalEffects 1.0

/*
  The overlay provides a blurred container with a title and a button to return to the previous screen
  It is shown/hidden using the visible property
  */
Item {
    id: overlay

    property alias background: backgroundImage.source
    property alias overlayTitle: header.text

    visible: false
    z: parent.z + 1
    anchors.fill: parent

    // Overlay Title
    Label {
        id: header
        anchors {
            horizontalCenter: parent.horizontalCenter
            top: parent.top
            topMargin: units.gu(2)
        }
        text: "Default"
        fontSize: "x-large"
        z: parent.z + 1
    }

    // Button to hide the overlay
    Button {
        id: footer
        anchors {
            horizontalCenter: parent.horizontalCenter
            bottom: parent.bottom
            margins: units.gu(2)
        }
        text: "Back"
        z: parent.z + 1
        width: parent.width/2
        onClicked: overlay.visible = false
    }

    // Background Image
    Image {
        id: backgroundImage
        anchors.fill: parent
    }

    // Element to blur the background image
    FastBlur {
        anchors.fill: backgroundImage
        source: backgroundImage
        radius: units.gu(8)
    }

    // Element to add a black curtain (dimmer) to increase the readiblity of the text
    Rectangle {
        color: "black"
        opacity: 0.7
        anchors.fill: parent
    }
}
