import QtQuick 2.0
import Ubuntu.Components 0.1
import "../../components"

Page {
    id: movieByGenrePage

    title: "Genre"
    visible: false
    flickable: null

    property string genre_id
    property string genre_url: root.baseUrl + "/genre/list" + root.api_Key
    property string genre_movie_url: root.baseUrl + "/genre/" + genre_id + "/movies" + root.api_Key

    Component.onCompleted: {
        genreWorker.source = "../../backend/GenreList.js"
        genreWorker.sendMessage({"url": genre_url, "model": genreListModel})
    }

    ListModel { id: genreListModel  }
    ListModel { id: genreMoviesModel  }

    WorkerScript { id: genreWorker }

    Flickable {
        clip: true
        anchors.fill: parent
        contentHeight: mainColumn.height + units.gu(5)
        interactive: contentHeight > parent.height

        Column {
            id: mainColumn

            anchors {
                left: parent.left;
                right: parent.right;
                top: parent.top;
                margins: units.gu(2)
            }

            spacing: units.gu(2)

            OptionSelector {
                text: "Choose movie genre"
                model: genreListModel
                delegate: genreDelegate
                onDelegateClicked: {
                    genreMoviesModel.clear()
                    genreWorker.source = "../../backend/GenreMovies.js"
                    genre_id = genreListModel.get(index).id
                    genreWorker.sendMessage({"model": genreMoviesModel, "url": genre_movie_url})
                }
            }

            Component {
                id: genreDelegate
                OptionSelectorDelegate { text: name }
            }

            Grid {
                id: movieList
                dataModel: genreMoviesModel
                visible: genreMoviesModel.count != 0
                height: units.gu(50)
                onThumbClicked: pageStack.push(Qt.resolvedUrl("MoviePage.qml"), {"movie_id": model.id})
            }
        }
    }
}
