import QtQuick 2.0
import Ubuntu.Components 0.1
import QtGraphicalEffects 1.0
import Ubuntu.Components.ListItems 0.1
import "../../components"

Page {
    id: moviePage

    visible: false
    flickable: null

    property string movie_id
    property string movie_url: root.baseUrl + "/movie/" + movie_id + root.api_Key + "&append_to_response=credits,similar_movies"

    Component.onCompleted: movieWorker.sendMessage({"movie_url": movie_url, "castModel": castModel, "crewModel": crewModel, "similarMovieModel": similarMovieModel})

    ListModel { id: castModel }
    ListModel { id: crewModel }
    ListModel { id: similarMovieModel }

    WorkerScript {
        id: movieWorker
        source: "../../backend/MovieDetails.js"
        onMessage: {
            thumb.source = messageObject.poster
            title.text = messageObject.title
            description.text = messageObject.description
            releaseDate.subText = messageObject.releasedate
            year.text = releaseDate.subText.split("-")[0]
            runTime.text = messageObject.runtime + " minutes"

            var genreModel = messageObject.genre
            for (var i=0; i<genreModel.length; i++) {
                if(genre.subText != "")
                    genre.subText = genre.subText + "," + genreModel[i].name
                else
                    genre.subText = genreModel[i].name
            }

            theme.subText = messageObject.theme
            rating.text = messageObject.avg_vote + "/10\n" + messageObject.total_vote

            cast1.text = castModel.get(0).name
            cast1.subText = castModel.get(0).character
            cast1.icon = castModel.get(0).iconUrl === "null" ? Qt.resolvedUrl("../../graphics/toolbarIcon.png") : castModel.get(0).iconUrl;

            cast2.text = castModel.get(1).name
            cast2.subText = castModel.get(1).character
            cast2.icon = castModel.get(1).iconUrl === "null" ? Qt.resolvedUrl("../../graphics/toolbarIcon.png") : castModel.get(1).iconUrl;

            cast3.text = castModel.get(2).name
            cast3.subText = castModel.get(2).character
            cast3.icon = castModel.get(2).iconUrl === "null" ? Qt.resolvedUrl("../../graphics/toolbarIcon.png") : castModel.get(2).iconUrl;

            crew1.text = crewModel.get(0).name
            crew1.subText = crewModel.get(0).job

            crew2.text = crewModel.get(1).name
            crew2.subText = crewModel.get(1).job

            crew3.text = crewModel.get(2).name
            crew3.subText = crewModel.get(2).job
        }
    }

    Overlay {
        id: summaryOverlay

        background: thumb.source
        overlayTitle: "Full Summary"

        Label {
            anchors {
                fill: parent
                leftMargin: units.gu(4)
                rightMargin: units.gu(4)
                topMargin: units.gu(12)
                bottomMargin: units.gu(12)
            }

            text: description.text
            wrapMode: Text.WordWrap
        }
    }

    Overlay {
        id: castOverlay

        background: thumb.source
        overlayTitle: "Full Cast"

        ListView {
            anchors {
                fill: parent
                leftMargin: units.gu(4)
                rightMargin: units.gu(4)
                topMargin: units.gu(12)
                bottomMargin: units.gu(12)
            }
            clip: true
            model: castModel

            delegate: Subtitled {
                text: name
                subText: character
                icon: iconUrl == "null" ? Qt.resolvedUrl("../../graphics/toolbarIcon.png") : iconUrl
                onClicked: pageStack.push(Qt.resolvedUrl("../person/PersonPage.qml"), {"person_id": id})
            }
        }
    }

    Overlay {
        id: crewOverlay

        background: thumb.source
        overlayTitle: "Full Crew"

        ListView {
            anchors {
                fill: parent
                leftMargin: units.gu(4)
                rightMargin: units.gu(4)
                topMargin: units.gu(12)
                bottomMargin: units.gu(12)
            }
            clip: true
            model: crewModel

            delegate: Subtitled {
                text: name
                subText: job
                onClicked: pageStack.push(Qt.resolvedUrl("../person/PersonPage.qml"), {"person_id": id})
            }
        }
    }

    Flickable {
        id: flickable
        clip: true
        anchors.fill: parent
        contentHeight: movieThumb.height + ratingsRow.height + detailsColumn.height + units.gu(10)
        interactive: contentHeight > parent.height

        UbuntuShape {
            id: movieThumb

            width: units.gu(18)
            height: width + units.gu(10)
            anchors {
                top: parent.top
                left: parent.left
                margins: units.gu(2)
            }

            image: Image {
                id: thumb
                fillMode: Image.PreserveAspectFit
                smooth: true
            }

            ActivityIndicator {
                anchors.centerIn: parent
                running: thumb.status != Image.Ready ? true : false
            }
        }

        Column {
            id: movieColumn
            height: movieThumb.height
            width: parent.width - movieThumb.width
            anchors {
                top: parent.top
                left: movieThumb.right
                right: parent.right
                margins: units.gu(2)
            }

            spacing: units.gu(2)
            Label {
                id: title
                fontSize: "large"
                width: movieColumn.width
                maximumLineCount: 2
                elide: Text.ElideRight
                wrapMode: Text.WordWrap
            }

            Label {
                id: description
                fontSize: "medium"
                width: movieColumn.width
                height: movieColumn.height/2
                elide: Text.ElideRight
                wrapMode: Text.WordWrap
                MouseArea {
                    anchors.fill: parent
                    onClicked: summaryOverlay.visible = true
                }
            }

            Column {
                Label { id: year }
                Label { id: runTime }
            }
        }

        // Movie Ratings
        Row {
            id: ratingsRow
            anchors {
                top: movieThumb.bottom
                left: parent.left
                right: parent.right
                topMargin: units.gu(1)
                leftMargin: units.gu(2)
            }

            Image{
                id: star
                width: units.gu(5)
                source: Qt.resolvedUrl("../../graphics/rating.png")
                fillMode: Image.PreserveAspectFit
                smooth: true
            }

            Label { id: rating }
        }

        // Movie Details - Release dates, genre, movie theme etc.
        Column {
            id: detailsColumn
            anchors {
                left: parent.left
                right: parent.right
                top: ratingsRow.bottom
                margins: units.gu(2)
            }

            // FIXME: Retrieve proper trailer url
            Button {
                text: "Play Trailer"
                width: parent.width
                onClicked:  Qt.openUrlExternally("http://youtube.com/watch?v=SUXWAEX2jlg")
            }

            Header { text: "Details" }

            Subtitled {
                id: genre
                text: "Genre"
            }

            Subtitled {
                id: releaseDate
                text: "Release Date"
            }

            Subtitled {
                id: theme
                text: "Movie Theme"
                visible: theme.subText == "" ? false : true
            }

            Header { text: "Casts" }

            Subtitled {
                id: cast1;
                progression: true
                onClicked: pageStack.push(Qt.resolvedUrl("../person/PersonPage.qml"), {"person_id": castModel.get(0).id})
            }

            Subtitled {
                id: cast2;
                progression: true
                onClicked: pageStack.push(Qt.resolvedUrl("../person/PersonPage.qml"), {"person_id": castModel.get(1).id})
            }

            Subtitled {
                id: cast3;
                progression: true
                onClicked: pageStack.push(Qt.resolvedUrl("../person/PersonPage.qml"), {"person_id": castModel.get(2).id})
            }

            Standard {
                id: allCast
                text: "Full Cast"
                progression: true
                onClicked: castOverlay.visible = true
            }

            Header { text: "Production Crew" }

            Subtitled {
                id: crew1;
                progression: true
                onClicked: pageStack.push(Qt.resolvedUrl("../person/PersonPage.qml"), {"person_id": crewModel.get(0).id})
            }

            Subtitled {
                id: crew2;
                progression: true
                onClicked: pageStack.push(Qt.resolvedUrl("../person/PersonPage.qml"), {"person_id": crewModel.get(1).id})
            }

            Subtitled {
                id: crew3;
                progression: true
                onClicked: pageStack.push(Qt.resolvedUrl("../person/PersonPage.qml"), {"person_id": crewModel.get(2).id})
            }

            Standard {
                id: fullCrew
                text: "Full Crew"
                progression: true
                onClicked: crewOverlay.visible = true
            }

            Carousel {
                id: similarMovies
                dataModel: similarMovieModel
                header: i18n.tr("Similar Movies")
                onThumbClicked: pageStack.push(Qt.resolvedUrl("MoviePage.qml"), {"movie_id": model.id})
            }
        }
    }
}


