import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1
import "../../components"

Page {
    // Movie URLs
    readonly property string nowPlayingUrl: root.baseUrl + "/movie/now_playing" + root.api_Key;
    readonly property string upcomingUrl: root.baseUrl + "/movie/upcoming" + root.api_Key;

    flickable: null

    ListModel {
        id: nowPlayingModel
        Component.onCompleted: {
            homePageWorker.source =  "../../backend/NowPlayingMovie.js"
            homePageWorker.sendMessage({'model': nowPlayingModel, 'url': nowPlayingUrl})
        }
    }

    ListModel {
        id: upcomingMovieModel
        Component.onCompleted: {
            homePageWorker.source =  "../../backend/UpcomingMovie.js"
            homePageWorker.sendMessage({'model': upcomingMovieModel, 'url': upcomingUrl})
        }
    }

    WorkerScript { id: homePageWorker }

    Flickable {
        clip: true
        anchors.fill: parent
        contentHeight: mainHomeColumn.height + units.gu(5)
        interactive: contentHeight > parent.height

        Column {
            id: mainHomeColumn

            anchors {
                left: parent.left;
                right: parent.right;
                top: parent.top;
                margins: units.gu(1)
            }

            spacing: units.gu(1)

            Row {
                width: parent.width
                anchors {
                    left: parent.left;
                    right: parent.right
                }

                spacing: units.gu(2)

                Button {
                    id: search
                    text: "Search Movie"
                    width: parent.width/2 - units.gu(1)
                    onClicked: pageStack.push(Qt.resolvedUrl("SearchMovie.qml"))
                }
                Button {
                    id: suggest
                    text: "Suggest Movie"
                    width: parent.width/2 - units.gu(1)
                    enabled: false
                }
            }

            Carousel {
                id: nowPlaying
                dataModel: nowPlayingModel
                header: i18n.tr("Now Playing")
                onThumbClicked: pageStack.push(Qt.resolvedUrl("MoviePage.qml"), {"movie_id": model.id})
            }

            Carousel {
                id: upcomingMovies
                dataModel: upcomingMovieModel
                header: i18n.tr("Upcoming Movies")
                onThumbClicked: pageStack.push(Qt.resolvedUrl("MoviePage.qml"), {"movie_id": model.id})
            }

            Header { text: "Filter" }

            Standard {
                text: "By Genre"
                progression: true
                onClicked: pageStack.push(Qt.resolvedUrl("MovieByGenre.qml"))
            }

            Standard {
                text: "Top Rated"
                progression: true
                enabled: false
            }

            Standard {
                text: "Popular"
                progression: true
                enabled: false
            }
        }
    }
}
