import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1

Page {
    id: personPage

    visible: false
    flickable: null

    property string person_id
    property string person_url: root.baseUrl + "/person/" + person_id + root.api_Key + "&append_to_response=combined_credits"

    Component.onCompleted: personWorker.sendMessage({"person_url": person_url, "actedModel": actedModel, "directedModel": directedModel})

    ListModel { id: actedModel }
    ListModel { id: directedModel }

    WorkerScript {
        id: personWorker
        source: "../../backend/PersonDetails.js"
        onMessage: {
            if(messageObject.poster == null)
                thumb.source = Qt.resolvedUrl("../../graphics/toolbarIcon.png")
            else
                thumb.source = "http://d3gtl9l2a4fn1j.cloudfront.net/t/p/" + "w185/" + messageObject.poster

            name.text = messageObject.name
            biography.text = messageObject.biography == null ? "Biography not available" : messageObject.biography
            birthYear.text = messageObject.birthday == null ? "Not Available" : "Born: " + messageObject.birthday
            deathYear.text = messageObject.deathday == null ? "Not Available" :"Dead: " + messageObject.deathday
            birthPlace.text = messageObject.place_of_birth == null ? "Birth Place Not Available" : messageObject.place_of_birth
            contact.text = messageObject.homepage == null ? "Homepage Not Available" : messageObject.homepage
        }
    }

    Flickable {
        id: flickable
        clip: true
        anchors.fill: parent
        contentHeight: personThumb.height + personColumn.height + biography.height + detailsColumn.height
        interactive: contentHeight > parent.height

        UbuntuShape {
            id: personThumb

            width: units.gu(20)
            height: width + units.gu(8)
            anchors {
                top: parent.top
                left: parent.left
                margins: units.gu(2)
            }

            image: Image {
                id: thumb
                fillMode: Image.PreserveAspectFit
                smooth: true
            }

            ActivityIndicator {
                anchors.centerIn: parent
                running: thumb.status != Image.Ready ? true : false
            }
        }

        Column {
            id: personColumn
            height: personThumb.height
            width: parent.width - personThumb.width
            anchors {
                top: parent.top
                left: personThumb.right
                right: parent.right
                margins: units.gu(2)
            }

            spacing: units.gu(2)

            Label {
                id: name
                fontSize: "large"
                width: personColumn.width
                maximumLineCount: 2
                elide: Text.ElideRight
                wrapMode: Text.WordWrap
            }

            Column {
                Label {
                    id: birthPlace
                    fontSize: "medium"
                    width: personColumn.width
                    elide: Text.ElideRight
                    wrapMode: Text.WordWrap
                }

                Label {
                    id: birthYear
                    fontSize: "medium"
                    visible: text == "Not Available" ? false: true
                    width: personColumn.width
                    elide: Text.ElideRight
                    wrapMode: Text.WordWrap
                }

                Label {
                    id: deathYear
                    fontSize: "medium"
                    visible: text == "Dead: " || text == "Not Available" ? false : true
                    width: personColumn.width
                    elide: Text.ElideRight
                    wrapMode: Text.WordWrap
                }

                Label {
                    id: contact
                    fontSize: "medium"
                    width: personColumn.width
                    elide: Text.ElideRight
                    wrapMode: Text.WordWrap
                    MouseArea {
                        anchors.fill: parent
                        enabled: contact.text == "null" ? false : true
                        onClicked: Qt.openUrlExternally(contact.text)
                    }
                }
            }
        }

        Label {
            id: biography
            anchors {
                top: personColumn.bottom
                left: parent.left
                right: parent.right
                margins: units.gu(2)
            }

            fontSize: "medium"
            width: parent.width
            elide: Text.ElideRight
            wrapMode: Text.WordWrap
        }

        Column {
            id: detailsColumn
            anchors {
                top: biography.bottom
                left: parent.left
                right: parent.right
                margins: units.gu(2)
            }

            Header {
                text: "Acting"
                visible: actedModel.count !== 0
            }

            ListView {
                anchors {
                    left: parent.left
                    right: parent.right
                }

                height: units.gu(20)
                clip: true

                model: actedModel
                delegate: Subtitled {
                    icon: iconUrl == "null" ? Qt.resolvedUrl("../../graphics/toolbarIcon.png") : iconUrl
                    text: title
                    subText: character
                    onClicked: media_type == "movie" ? pageStack.push(Qt.resolvedUrl("../movie/MoviePage.qml"), {"movie_id": id}) : console.log("Not a movie")
                }
            }

            Header {
                text: "Production"
                visible: directedModel.count !== 0
            }

            ListView {
                anchors {
                    left: parent.left
                    right: parent.right
                }

                height: units.gu(20)
                clip: true

                model: directedModel
                delegate: Subtitled {
                    icon: iconUrl == "null" ? Qt.resolvedUrl("../../graphics/toolbarIcon.png") : iconUrl
                    text: title
                    subText: character
                    onClicked: media_type == "movie" ? pageStack.push(Qt.resolvedUrl("../movie/MoviePage.qml"), {"movie_id": id}) : console.log("Not a movie")
                }
            }
        }
    }
}
